@@ -22,7 +22,7 @@ our @EXPORT = qw(
 
 our $Debug = 0;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 sub to_utf8 {
     my $str = shift;
@@ -30,14 +30,17 @@ sub to_utf8 {
 
     # checks first
     if ( is_flagged_utf8($str) ) {
+        $Debug and carp "string '$str' is flagged utf8 already";
         return $str;
     }
     if ( is_valid_utf8($str) ) {
         Encode::_utf8_on($str);
+        $Debug and carp "string '$str' is valid utf8; utf8 flag turned on";
         return $str;
     }
     if ( is_ascii($str) ) {
         Encode::_utf8_on($str);
+        $Debug and carp "string '$str' is ascii; utf8 flag turned on";
         return $str;
     }
 
